@@ -90,6 +90,16 @@ class OssFileCache():
         except oss2.exceptions.NoSuchKey:
             return False
 
+    def exist(self, key):
+        """
+        判断缓存文件是否存在
+        :param key:
+        :return: True|False
+        """
+        cache_path = "%s/%s/%s" % (self.cache_path_root, self.namespace, key)
+
+        return self.bucket.object_exists(cache_path)
+
     def list_cache_objects(self):
         """
         获取文件夹OSS缓存文件
